@@ -8,6 +8,10 @@ Created on Mon May  3 11:39:55 2021
 def constrain_field(Constraints,u = None,v = None,w = None, BaseName = 'Turb', \
                         alphaepsilon = 1,L = 30,Gamma = 3, Nx = 8192, Ny = 32, Nz = 32, \
                         dx = 1,dy = 1,dz = 1,SaveToFile = 0, UseNormalization = 0, TurbOptions = None):
+
+    import numpy as np
+    import time
+
     '''
     Parse inputs 
     '''
@@ -37,12 +41,15 @@ def constrain_field(Constraints,u = None,v = None,w = None, BaseName = 'Turb', \
             from hipersim.turbgen.generate_field import generate_field 
             u,v,w = generate_field(BaseName,alphaepsilon,L,Gamma,SeedNo,Nx,Ny,Nz,dx,dy,dz, \
                                     HighFreqComp, SaveToFile = 0)
+        else:
             '''
             Load source turbulence boxes 
             '''
+            u = np.fromfile(TurbOptions['Udatafile'],dtype = 'single').reshape((Nx,Ny,Nz))
+            v = np.fromfile(TurbOptions['Udatafile'],dtype = 'single').reshape((Nx,Ny,Nz))
+            w = np.fromfile(TurbOptions['Udatafile'],dtype = 'single').reshape((Nx,Ny,Nz))
+            
 
-    import numpy as np
-    import time
     # from generate_field import generate_field
     # Nx = 1024
     # Ny = 32
@@ -76,52 +83,7 @@ def constrain_field(Constraints,u = None,v = None,w = None, BaseName = 'Turb', \
     #                               np.concatenate([Vconstraints, -Vconstraints]),
     #                               np.concatenate([Wconstraints, -Wconstraints])],axis = 1)
         
-    # % If not given as inputs, load turbulence boxes from files or generate them if necessary
-    
-    # if ~exist('u','var') || ~exist('v','var') || ~exist('w','var')
-    #     if ~isfield(Input,'Udatafile') || ~isfield(Input,'Vdatafile') || ~isfield(Input,'Wdatafile')
-    #         disp('Source turbulence boxes are not specified for all components to be constrained. Generating turbulence boxes instead.');
-    #         [u,v,w] = MannGenerator(Input,Options);
-    #     else
-    #         disp('Loading turbulence boxes..');
-    #         Ufile = fopen(Input.Udatafile);
-    #         Udata = fread(Ufile,'single');
-    #         fclose(Ufile);
-    #         u = zeros(Nx,Ny,Nz);
-    #         for xloc = 1:Nx
-    #             for yloc = 1:Ny
-    #                 dataindex = Ny*Nz*(xloc - 1) + Ny*(yloc-1);
-    #                 UperZ = Udata(dataindex+1:dataindex+Nz);
-    #                 u(xloc,yloc,:) = UperZ;
-    #             end
-    #         end
-    #         clear Udata;     
-    #         Vfile = fopen(Input.Vdatafile);
-    #         Vdata = fread(Vfile,'single');
-    #         fclose(Vfile);
-    #         v = zeros(Nx,Ny,Nz);                  
-    #         for xloc = 1:Nx
-    #             for yloc = 1:Ny
-    #                 dataindex = Ny*Nz*(xloc - 1) + Ny*(yloc-1);
-    #                 VperZ = Vdata(dataindex+1:dataindex+Nz);
-    #                 v(xloc,yloc,:) = VperZ;
-    #             end
-    #         end
-    #         clear Vdata;   
-    #         Wfile = fopen(Wdatafile);
-    #         Wdata = fread(Wfile,'single');
-    #         fclose(Wfile);                   
-    #         w = zeros(Nx,Ny,Nz);
-    #         for xloc = 1:Nx
-    #             for yloc = 1:Ny
-    #                 dataindex = Ny*Nz*(xloc - 1) + Ny*(yloc-1);
-    #                 WperZ = Wdata(dataindex+1:dataindex+Nz);
-    #                 w(xloc,yloc,:) = WperZ;
-    #             end
-    #         end        
-    #         clear Wdata;  
-    #     end
-    # end
+
     
     ''' 
     ===============================================
