@@ -5,7 +5,7 @@ Created on Mon May  3 11:39:55 2021
 @author: nkdi
 """
 
-def constrain_field_1d(Constraints, Component = None,u = None, BaseName = 'Turb', \
+def constrain_field_1d(Constraints, Component = None,c = None, BaseName = 'Turb', \
                         alphaepsilon = 1,L = 30,Gamma = 3, Nx = 8192, Ny = 32, Nz = 32, \
                         dx = 1,dy = 1,dz = 1,SaveToFile = 0, UseNormalization = 0, TurbOptions = None):
     import numpy as np
@@ -33,7 +33,7 @@ def constrain_field_1d(Constraints, Component = None,u = None, BaseName = 'Turb'
         else:
             HighFreqComp = TurbOptions['HighFreqComp']
     
-    if (u is None):
+    if (c is None):
         if Component == 'u':
             if 'Udatafile' not in TurbOptions:
                 print('Source turbulence boxes for constrained simulation do not exist.')
