@@ -127,11 +127,16 @@ class turb_field:
 
             if (((Component == 'u') & (hasattr(self,'u')==False)) | ((Component == 'v') & (hasattr(self,'v')==False)) | ((Component == 'w') & (hasattr(self,'w')==False))):
                 self.generate()
-            c = constrain_field_1d(Component, 
+            if Component == 'u':
+                c_0 = self.u
+            if Component == 'v':
+                c_0 = self.v
+            if Component == 'w':
+                c_0 = self.w                
+            c = constrain_field_1d( 
                                    Constraints,
-                                   self.u,
-                                   self.v,
-                                   self.w,
+                                   Component,
+                                   c = c_0,
                                    BaseName = self.params['BaseName'],
                                    alphaepsilon = self.params['alphaepsilon'],
                                    L = self.params['L'],
